.. Biggus documentation master file, created by
   sphinx-quickstart on Fri Feb 28 13:12:30 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Biggus's documentation!
==================================

.. automodule:: biggus

.. toctree::

    creation
    computation


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

